@@ -167,13 +167,45 @@ impl<SPI: Spi, SCLK: OutputPin, SDO: OutputPin, SDI: InputPin + OutputPin, CS: O
         pins: Pins<SCLK, SDO, SDI, CS>,
         config: config::Config,
     ) -> Result<Self, EspError> {
+        #[cfg(esp_idf_version = "4.4")]
         let bus_config = spi_bus_config_t {
             flags: SPICOMMON_BUSFLAG_MASTER,
+            sclk_io_num: SCLK::pin(),
+
+            data4_io_num: -1,
+            data5_io_num: -1,
+            data6_io_num: -1,
+            data7_io_num: -1,
+            __bindgen_anon_1: spi_bus_config_t__bindgen_ty_1 {
+                mosi_io_num: SDO::pin(),
+                //data0_io_num: -1,
+            },
+            __bindgen_anon_2: spi_bus_config_t__bindgen_ty_2 {
+                miso_io_num: if pins.sdi.is_some() { SDI::pin() } else { -1 },
+                //data1_io_num: -1,
+            },
+            __bindgen_anon_3: spi_bus_config_t__bindgen_ty_3 {
+                quadwp_io_num: -1,
+                //data2_io_num: -1,
+            },
+            __bindgen_anon_4: spi_bus_config_t__bindgen_ty_4 {
+                quadhd_io_num: -1,
+                //data3_io_num: -1,
+            },
+            //max_transfer_sz: SPI_MAX_TRANSFER_SIZE,
+            ..Default::default()
+        };
+
+        #[cfg(not(esp_idf_version = "4.4"))]
+        let bus_config = spi_bus_config_t {
+            flags: SPICOMMON_BUSFLAG_MASTER,
+            sclk_io_num: SCLK::pin(),
+
             mosi_io_num: SDO::pin(),
             miso_io_num: if pins.sdi.is_some() { SDI::pin() } else { -1 },
-            sclk_io_num: SCLK::pin(),
             quadwp_io_num: -1,
             quadhd_io_num: -1,
+
             //max_transfer_sz: SPI_MAX_TRANSFER_SIZE,
             ..Default::default()
         };
@@ -213,6 +245,7 @@ impl<SPI: Spi, SCLK: OutputPin, SDO: OutputPin, SDI: InputPin + OutputPin, CS: O
     }
 
     /// Release and return the raw interface to the underlying SPI peripheral
+    #[allow(clippy::type_complexity)]
     pub fn release(self) -> Result<(SPI, Pins<SCLK, SDO, SDI, CS>), EspError> {
         esp!(unsafe { spi_bus_remove_device(self.device) })?;
         esp!(unsafe { spi_bus_free(SPI::device()) })?;
@@ -228,8 +261,8 @@ impl<SPI: Spi, SCLK: OutputPin, SDO: OutputPin, SDI: InputPin + OutputPin, CS: O
     where
         T: Word,
     {
-        let mut tx_buffer = [0 as u8; 64];
-        let mut rx_buffer = [0 as u8; 64];
+        let mut tx_buffer = [0_u8; 64];
+        let mut rx_buffer = [0_u8; 64];
 
         let mut transaction = spi_transaction_t {
             flags: 0, //SPI_TRANS_USE_RXDATA|SPI_TRANS_USE_TXDATA,
@@ -279,11 +312,11 @@ impl<SPI: Spi, SCLK: OutputPin, SDO: OutputPin, SDI: InputPin + OutputPin, CS: O
     ///
     /// This function locks the APB bus frequency and chunks the output of the iterator
     /// for maximum write performance.
-    fn write_internal<'a, T>(&mut self, words: &'a [T]) -> Result<(), EspError>
+    fn write_internal<T>(&mut self, words: &'_ [T]) -> Result<(), EspError>
     where
         T: Word,
     {
-        let mut tx_buffer = [0 as u8; 64];
+        let mut tx_buffer = [0_u8; 64];
 
         let mut transaction = spi_transaction_t {
             flags: 0, //SPI_TRANS_USE_RXDATA|SPI_TRANS_USE_TXDATA,
@@ -326,7 +359,7 @@ impl<SPI: Spi, SCLK: OutputPin, SDO: OutputPin, SDI: InputPin + OutputPin, CS: O
         T: Word,
         WI: IntoIterator<Item = T>,
     {
-        let mut tx_buffer = [0 as u8; 64];
+        let mut tx_buffer = [0_u8; 64];
 
         let mut transaction = spi_transaction_t {
             flags: 0, //SPI_TRANS_USE_RXDATA|SPI_TRANS_USE_TXDATA,
@@ -598,6 +631,9 @@ macro_rules! impl_spi {
         pub struct $spi(SpiPrivateField);
 
         impl $spi {
+            /// # Safety
+            ///
+            /// Care should be taken not to instantiate this SPI instance, if it is already instantiated and used elsewhere
             pub unsafe fn new() -> Self {
                 $spi(SpiPrivateField)
             }
